########################################################################
# This script is used to calculate the mean of the observations
# April 2023
########################################################################

# Step (1): Load the libraries
library(CSTools)
library(lubridate)
library(s2dv)
library(ClimProjDiags)

# Step (2): Create daily data
obs <- array(1:90, dim = c(day = 90))

# Step (3): Create the dates
dates <- seq(ymd('2023-04-01'), ymd('2023-04-01') + days(89), by = 'day')

# Step (4): Add dimension month to data
indices_month <- month(dates)
data_month <- SplitDim(obs, split_dim = 'day', indices = indices_month, 
                       new_dim_name = 'month')

# Step (5): Compute the mean
data_montly_mean <- MeanDims(data_month, dims = 'day', na.rm = TRUE)

########################################################################
# Example 2: Compute only the daily average

# Stp (1): Create hourly data
data_hourly <- array(1:217, dim = c(hours = 217))

# Step (2): Create the dates
dates <- seq(ymd_hms("2023-04-25 00:00:00"), ymd_hms("2023-04-25 00:00:00") + days(9), by = 'hour')

# Step (3): Add dimension hour to data
indices_hour <- hour(dates)
data_month <- SplitDim(data_hourly, split_dim = 'hours', indices = indices_hour, 
                       new_dim_name = 'hour')

